@@ -77,7 +77,27 @@ class CrsTransform(object):
         s = vCRS.get_by_idx(self.map2crs[2]);        
         return v3.VectorThree(c,r,s);
 
-        
+    def convert_coords_to_xyz(self,crs_coords):
+        coords = []
+        for i in range(len(crs_coords)):
+            row = []
+            for j in range(len(crs_coords[0])):
+                vec = v3.VectorThree(crs_coords[i][j][0],crs_coords[i][j][1],0)
+                vec_t = self.crs_to_xyz(vec)
+                row.append(vec_t)
+            coords.append(row)
+        return coords
+    
+    def convert_coords_to_crs(self,xyz_coords):
+        coords = []
+        for i in range(len(xyz_coords)):
+            row = []
+            for j in range(len(xyz_coords[0])):
+                vec = v3.VectorThree(xyz_coords[i][j][0],xyz_coords[i][j][1],0)
+                vec_t = self.xyz_to_crs(vec)
+                row.append(vec_t)
+            coords.append(row)
+        return coords
 
     ########## PRIVATE INTERFACE #############
     def _make_ortho(self):        
